Learn R Programming

tabledown (version 1.0.0)

ggtestinfo: A Function for Creating Publication Quality Item Response Theory based test information plot.

Description

This function will create publication worthy Item Response Theory based Test information plot using ggplot2 from objects created from mirt pack. Using ggplot2 will enable the user to modify the Item plot.

Usage

ggtestinfo(dataframe, model)

Value

A publication quality Test information plot. Output object is a ggplot object.

Arguments

dataframe

your data.

model

A mirt package fitted object.

Examples

Run this code
data <- tabledown::Rotter[, 11:31]
model <- mirt::mirt(data, model = 1, itemtype = '2PL')

plot <- ggtestinfo(data, model)

Run the code above in your browser using DataLab