Learn R Programming

tabledown (version 1.0.0)

ggtestinfo_se_ploty: A Function for Creating Item Response Theory based test information plot with standard error with plotly.

Description

This function will create Item Response Theory based Test information plot with standard error using ggplot2 and plotly from objects created from mirt pack. Using ggplot2 will enable the user to modify the Item plot.

Usage

ggtestinfo_se_ploty(dataframe, model)

Value

A publication quality Test information plot with standard error (dashed line). Output object is a ggplot object.

Arguments

dataframe

your data.

model

A mirt package fitted object.

Examples

Run this code
data <- tabledown::Rotter[, 11:31]
model <- mirt::mirt(data, model = 1, itemtype = '2PL')
plot <- ggtestinfo_se_ploty(data, model)

Run the code above in your browser using DataLab