Learn R Programming

tabledown (version 1.0.0)

ggiteminfo: A Function for Creating Publication Quality Item Response Theory based item information plot.

Description

This function will create publication worthy Item Response Theory based item information plot. using ggplot2 from objects created from mirt pack.

Usage

ggiteminfo(model, item, theta)

Value

A publication quality item information plot.Output object is a ggplot object.

Arguments

model

A mirt package fitted object.

item

Item number (i.e. 1,2,3,4).

theta

Theta range. Put only one number. Theta =3 will be considered as theta range (-3 to 3).

Examples

Run this code
data <- tabledown::Rotter[, 11:31]
model <- mirt::mirt(data, model = 1, itemtype = '2PL')

plot <- ggiteminfo(model, 1, 3)

Run the code above in your browser using DataLab