ggtestinfo: A Function for Creating Publication Quality Item Response Theory based test information plot.
Description
This function will create publication worthy Item Response Theory based Test information plot using ggplot2 from objects created from
mirt pack.
Using ggplot2 will enable the user to modify the Item plot.
Usage
ggtestinfo(dataframe, model)
Value
A publication quality Test information plot. Output object is a ggplot object.